summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJesse Chappell <jesse@essej.net>2006-12-27 05:29:58 +0000
committerJesse Chappell <jesse@essej.net>2006-12-27 05:29:58 +0000
commit5c0764e90d43cb7b0f6195071a47c9232b91bfb7 (patch)
tree03fd41d039836af63f114942f5bf83a0755065e1
parent7d95ab884a3529978e36f72471c1afa1938b074a (diff)
updated osx icon. use ARDOUR_MODULE_PATH in osx exporter script. fixed control protocol search to look for .dylib as well as .so.
git-svn-id: svn://localhost/ardour2/trunk@1249 d708f5d6-7413-0410-9779-e7cbd77b26cf
-rw-r--r--libs/ardour/control_protocol_manager.cc8
-rw-r--r--tools/osx_packaging/Ardour2.icnsbin53885 -> 41196 bytes
-rwxr-xr-xtools/osx_packaging/app_build.rb14
-rwxr-xr-xtools/osx_packaging/bin/exporter1
4 files changed, 15 insertions, 8 deletions
diff --git a/tools/osx_packaging/Ardour2.icns b/tools/osx_packaging/Ardour2.icns
index 0e345fc120..2334fab13b 100644
--- a/tools/osx_packaging/Ardour2.icns
+++ b/tools/osx_packaging/Ardour2.icns
Binary files differ
diff --git a/tools/osx_packaging/app_build.rb b/tools/osx_packaging/app_build.rb
index 443b287c28..c81225024b 100755
--- a/tools/osx_packaging/app_build.rb
+++ b/tools/osx_packaging/app_build.rb
@@ -3,7 +3,10 @@
# Ruby script for pulling together a MacOSX app bundle.
# it will be either powerpc or i386
-version = "beta9"
+versionline = `grep -m 1 '^version =' ../../SConstruct`
+version = versionline.split(" = ")[1].chomp().slice(1..-2)
+$stdout.printf("Version is %s\n", version)
+
arch = `uname -p`.strip()
libdir = "lib_" + arch
bindir = "bin_" + arch
@@ -180,7 +183,7 @@ if File.exist?(ppc_libdir) and File.exist?(i386_libdir) then
$stdout.print("\nRunning Playtpus to create Ardour2.app ...\n");
- `/usr/local/bin/platypus -D -X 'ardour' -a 'Ardour2' -t 'shell' -o 'None' -u 'Paul Davis' -i '/bin/sh' -V '2.0' -s 'ArDr' -I 'org.ardour.Ardour2' -f 'bin' -f 'lib' -i 'Ardour2.icns' -f 'MenuBar.nib' -f 'ProgressWindow.nib' -f 'init' -f 'openDoc' 'script' 'Ardour2.app'`
+ `/usr/local/bin/platypus -D -X 'ardour' -a 'Ardour2' -t 'shell' -o 'None' -u 'Paul Davis' -i '/bin/sh' -V "#{version}" -s 'ArDr' -I 'org.ardour.Ardour2' -f 'bin' -f 'lib' -i 'Ardour2.icns' -f 'MenuBar.nib' -f 'ProgressWindow.nib' -f 'init' -f 'openDoc' 'script' 'Ardour2.app'`
$stdout.print("\nCopying other stuff to Ardour2.app ...\n");
@@ -233,7 +236,7 @@ if File.exist?(ppc_libdir) and File.exist?(i386_libdir) then
`rm -rf macdist`
Dir.mkdir("macdist")
`cp -r README.rtf COPYING Ardour2.app macdist/`
- dmgname = "Ardour2-#{version}"
+ dmgname = "Ardour-#{version}"
`rm -f #{dmgname}.dmg`
$stdout.print("\nCreating DMG\n")
`hdiutil create -fs HFS+ -volname #{dmgname} -srcfolder macdist #{dmgname}.dmg`
@@ -244,9 +247,10 @@ if File.exist?(ppc_libdir) and File.exist?(i386_libdir) then
else
# zip up libdir and bindir
zipfile = "binlib_"+`uname -p`.strip() + ".zip"
- $stdout.print("\nZipping up #{libdir} and #{bindir} into #{zipfile}\n")
- $stdout.print("Copy #{zipfile} to other platform's osx_packaging dir and run app_build.rb\nthere to complete universal build.\n")
+ $stdout.print("Zipping up #{libdir} and #{bindir} into #{zipfile}...\n")
`zip -rq #{zipfile} #{libdir} #{bindir}`
+ $stdout.print("Copy #{zipfile} to other platform's osx_packaging dir and run app_build.rb\nthere to complete universal build.\n")
+
end
diff --git a/tools/osx_packaging/bin/exporter b/tools/osx_packaging/bin/exporter
index cf77284796..41a2904ff9 100755
--- a/tools/osx_packaging/bin/exporter
+++ b/tools/osx_packaging/bin/exporter
@@ -20,6 +20,7 @@ export LANG=`grep '\b'\`defaults read .GlobalPreferences AppleCollationOrder\`_\
export ARDOUR2_UI_RC=ardour2_ui.rc
export ARDOUR_CONFIG_PATH="$TOP/etc"
+export ARDOUR_MODULE_PATH="$TOP/lib/"
export ARDOUR_DATA_PATH="$TOP/share"
export ARDOUR_GLADE_PATH="$TOP/share/ardour2/glade"
diff --git a/libs/ardour/control_protocol_manager.cc b/libs/ardour/control_protocol_manager.cc
index 495a66465e..de177d0e3d 100644
--- a/libs/ardour/control_protocol_manager.cc
+++ b/libs/ardour/control_protocol_manager.cc
@@ -154,9 +154,11 @@ ControlProtocolManager::teardown (ControlProtocolInfo& cpi)
static bool protocol_filter (const string& str, void *arg)
{
- /* Not a dotfile, has a prefix before a period, suffix is "so" */
+ /* Not a dotfile, has a prefix before a period, suffix is "so", or "dylib" */
- return str[0] != '.' && (str.length() > 3 && str.find (".so") == (str.length() - 3));
+ return str[0] != '.'
+ && ((str.length() > 3 && str.find (".so") == (str.length() - 3))
+ || (str.length() > 6 && str.find (".dylib") == (str.length() - 6)));
}
void
@@ -180,7 +182,7 @@ ControlProtocolManager::discover_control_protocols (string path)
vector<string *> *found;
PathScanner scanner;
- // info << string_compose (_("looking for control protocols in %1"), path) << endmsg;
+ info << string_compose (_("looking for control protocols in %1"), path) << endmsg;
found = scanner (path, protocol_filter, 0, false, true);